@@ -9,10 +9,11 @@ package Lemonldap::NG::Portal::AuthOpenID;
 use strict;
 use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Common::Regexp;
-use LWP::UserAgent;
+use Lemonldap::NG::Portal::_Browser;
 use Cache::FileCache;
 
-our $VERSION = '1.2.2_01';
+our @ISA     = (qw(Lemonldap::NG::Portal::_Browser));
+our $VERSION = '1.4.11';
 our $initDone;
 
 BEGIN {
@@ -48,11 +49,8 @@ sub authInit {
 sub extractFormInfo {
     my $self = shift;
 
-    my $ua = LWP::UserAgent->new();
-
-    # TODO : LWP options to use a proxy for example
     $self->{csr} = Net::OpenID::Consumer->new(
-        ua              => $ua,
+        ua              => $self->ua(),
         cache           => $self->{refLocalStorage} || Cache::FileCache->new,
         args            => $self,
         consumer_secret => $self->{openIdSecret},
@@ -79,7 +77,7 @@ sub extractFormInfo {
 
         # If confirmation is needed
         if ( my $setup_url = $csr->user_setup_url ) {
-            $self->lmLog( 'OpenID confirmation needed', 'info' );
+            $self->_sub( 'userInfo', 'OpenID confirmation needed' );
             print $self->redirect($setup_url);
             $self->quit();
         }
@@ -111,11 +109,12 @@ sub extractFormInfo {
     # 3. Check if an OpenID url has been submitted
     else {
         my $tmp = $url;
-        $tmp =~ m#^http//(.*?)/#;
+        $tmp =~ m#^https?://(.*?)/#;
         if ( $tmp =~
             $self->{_reopenIdIDPList} xor $self->{_openIdIDPListIsWhite} )
         {
-            $self->lmLog( "$url is forbidden for openID exchange", 'warn' );
+            $self->_sub( 'userNotice',
+                "$url is forbidden for openID exchange" );
             $self->{_msg} =
               "OpenID error: $tmp is forbidden for OpenID echange";
             return PE_BADPARTNER;
@@ -150,11 +149,10 @@ sub extractFormInfo {
         # compatible fields
         if ( $self->get_module('user') eq 'OpenID' ) {
             my ( @r, @o );
-            while ( my ( $v, $k ) = each %{ $self->{exportedVars} } ) {
-                if ( $k =~
-/^(?:(?:(?:full|nick)nam|languag|postcod|timezon)e|country|gender|email|dob)$/
-                  )
-                {
+            my %vars =
+              ( %{ $self->{exportedVars} }, %{ $self->{openIdExportedVars} } );
+            while ( my ( $v, $k ) = each %vars ) {
+                if ( $k =~ Lemonldap::NG::Common::Regexp::OPENIDSREGATTR() ) {
                     if   ( $v =~ s/^!// ) { push @r, $k }
                     else                  { push @o, $k }
                 }
@@ -244,12 +242,12 @@ compatible portals with OpenID authentication.
   if($portal->process()) {
     # Write here the menu with CGI methods. This page is displayed ONLY IF
     # the user was not redirected here.
-    print $portal->header('text/html; charset=utf8'); # DON'T FORGET THIS (see CGI(3))
+    print $portal->header('text/html; charset=utf-8'); # DON'T FORGET THIS (see CGI(3))
     print "...";
   }
   else {
     # If the user enters here, IT MEANS THAT CAS REDIRECTION DOES NOT WORK
-    print $portal->header('text/html; charset=utf8'); # DON'T FORGET THIS (see CGI(3))
+    print $portal->header('text/html; charset=utf-8'); # DON'T FORGET THIS (see CGI(3))
     print "<html><body><h1>Unable to work</h1>";
     print "This server isn't well configured. Contact your administrator.";
     print "</body></html>";
@@ -269,8 +267,13 @@ L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
-Thomas Chemineau, E<lt>thomas.chemineau@linagora.comE<gt>,
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=back
 
 =head1 BUG REPORT
 
@@ -284,11 +287,26 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Copyright (C) 2010 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2010, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
 
