@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_SAML;    #inherits
 use Lemonldap::NG::Common::Conf::SAML::Metadata;
 
-our $VERSION = '1.4.10';
+our $VERSION = '1.4.11';
 our @ISA     = qw(Lemonldap::NG::Portal::_SAML);
 
 ## @apmethod int authInit()
@@ -1130,7 +1130,18 @@ sub setAuthSessionInfo {
     # Dump Lasso objects in session
     $self->{sessionInfo}->{_lassoSessionDump}  = $session->dump()  if $session;
     $self->{sessionInfo}->{_lassoIdentityDump} = $identity->dump() if $identity;
-    $self->{sessionInfo}->{_samlToken} = $self->{_samlToken};
+
+    # Keep SAML Token in session
+    my $store_samlToken =
+      $self->{samlIDPMetaDataOptions}->{$idpConfKey}
+      ->{samlIDPMetaDataOptionsStoreSAMLToken};
+    if ($store_samlToken) {
+        $self->lmLog( "Store SAML Token in session", 'debug' );
+        $self->{sessionInfo}->{_samlToken} = $self->{_samlToken};
+    }
+    else {
+        $self->lmLog( "SAML Token will not be stored in session", 'debug' );
+    }
 
     $self->{_lassoLogin} = $login;
 
@@ -1284,11 +1295,11 @@ sub authLogout {
         $method = $self->getFirstHttpMethod( $server, $idp, $protocolType );
     }
 
-    # Failback to SOAP
+    # Skip SLO if no method found
     unless ( defined $method and $method != -1 ) {
         $self->lmLog( "No method found with IDP $idpConfKey for SLO profile",
             'debug' );
-        $method = $self->getHttpMethod("soap");
+        return PE_OK;
     }
 
     $self->lmLog(
