@@ -9,8 +9,9 @@ use strict;
 use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_CAS;
 use base qw(Lemonldap::NG::Portal::_CAS Lemonldap::NG::Portal::_LibAccess);
+use URI;
 
-our $VERSION = '1.4.2';
+our $VERSION = '1.4.9';
 
 ## @method void issuerDBInit()
 # Nothing to do
@@ -136,18 +137,37 @@ sub issuerForUnAuthUser {
 
         $self->lmLog( "Service ticket session $ticket found", 'debug' );
 
-        # Check service
-        unless ( $service eq $casServiceSession->data->{service} ) {
-            $self->lmLog(
-                "Submitted service $service does not match initial service "
-                  . $casServiceSession->data->{service},
-                'error'
-            );
-            $self->returnCasValidateError();
-        }
+        my $service1_uri = URI->new($service);
+        my $service2_uri = URI->new( $casServiceSession->data->{service} );
 
-        $self->lmLog( "Submitted service $service math initial servce",
-            'debug' );
+        # Check service
+        unless ( $service1_uri->eq($service2_uri) ) {
+
+            # Tolerate that relative URI are the same
+            if (   $service1_uri->rel($service2_uri) eq "./"
+                or $service2_uri->rel($service1_uri) eq "./" )
+            {
+                $self->lmLog(
+"Submitted service $service1_uri does not exactly match initial service "
+                      . $service2_uri
+                      . ' but difference is tolerated.',
+                    'warn'
+                );
+            }
+            else {
+                $self->lmLog(
+                    "Submitted service $service does not match initial service "
+                      . $casServiceSession->data->{service},
+                    'error'
+                );
+                $self->deleteCasSession($casServiceSession);
+                $self->returnCasValidateError();
+            }
+        }
+        else {
+            $self->lmLog( "Submitted service $service math initial servce",
+                'debug' );
+        }
 
         # Check renew
         if ( $renew eq 'true' ) {
@@ -160,6 +180,7 @@ sub issuerForUnAuthUser {
 "Authentication renew requested, but not done in former authentication process",
                     'error'
                 );
+                $self->deleteCasSession($casServiceSession);
                 $self->returnCasValidateError();
             }
         }
@@ -175,6 +196,7 @@ sub issuerForUnAuthUser {
                   . " notfound",
                 'error'
             );
+            $self->deleteCasSession($casServiceSession);
             $self->returnCasValidateError();
         }
 
@@ -185,6 +207,7 @@ sub issuerForUnAuthUser {
         $self->lmLog( "Get username $username", 'debug' );
 
         # Return success message
+        $self->deleteCasSession($casServiceSession);
         $self->returnCasValidateSuccess($username);
 
         # We should not be there
@@ -255,23 +278,39 @@ sub issuerForUnAuthUser {
 
         $self->lmLog( "$urlType ticket session $ticket found", 'debug' );
 
+        my $service1_uri = URI->new($service);
+        my $service2_uri = URI->new( $casServiceSession->data->{service} );
+
         # Check service
-        unless ( $service eq $casServiceSession->data->{service} ) {
-            $self->lmLog(
-                "Submitted service $service does not match initial service "
-                  . $casServiceSession->data->{service},
-                'error'
-            );
+        unless ( $service1_uri->eq($service2_uri) ) {
 
-            # CAS protocol: invalidate ticket if service is invalid
-            $self->deleteCasSession($casServiceSession);
+            # Tolerate that relative URI are the same
+            if (   $service1_uri->rel($service2_uri) eq "./"
+                or $service2_uri->rel($service1_uri) eq "./" )
+            {
+                $self->lmLog(
+"Submitted service $service1_uri does not exactly match initial service "
+                      . $service2_uri
+                      . ' but difference is tolerated.',
+                    'warn'
+                );
+            }
+            else {
+                $self->lmLog(
+                    "Submitted service $service does not match initial service "
+                      . $casServiceSession->data->{service},
+                    'error'
+                );
 
-            $self->returnCasServiceValidateError( 'INVALID_SERVICE',
-                'Submitted service does not match initial service' );
+                $self->deleteCasSession($casServiceSession);
+                $self->returnCasServiceValidateError( 'INVALID_SERVICE',
+                    'Submitted service does not match initial service' );
+            }
+        }
+        else {
+            $self->lmLog( "Submitted service $service match initial service",
+                'debug' );
         }
-
-        $self->lmLog( "Submitted service $service match initial servce",
-            'debug' );
 
         # Check renew
         if ( $renew eq 'true' ) {
@@ -284,6 +323,7 @@ sub issuerForUnAuthUser {
 "Authentication renew requested, but not done in former authentication process",
                     'error'
                 );
+                $self->deleteCasSession($casServiceSession);
                 $self->returnCasValidateError();
             }
 
@@ -382,6 +422,7 @@ sub issuerForUnAuthUser {
                   . " notfound",
                 'error'
             );
+            $self->deleteCasSession($casServiceSession);
             $self->returnCasServiceValidateError( 'INTERNAL_ERROR',
                 'No session associated to ticket' );
         }
@@ -393,6 +434,7 @@ sub issuerForUnAuthUser {
         $self->lmLog( "Get username $username", 'debug' );
 
         # Return success message
+        $self->deleteCasSession($casServiceSession);
         $self->returnCasServiceValidateSuccess( $username,
             $casProxyGrantingTicketIOU, $proxies );
 
