@@ -71,7 +71,7 @@ use Digest::MD5;
 #inherits Apache::Session
 #link Lemonldap::NG::Common::Apache::Session::SOAP protected globalStorage
 
-our $VERSION = '1.4.9';
+our $VERSION = '1.4.10';
 
 use base qw(Lemonldap::NG::Common::CGI Exporter);
 our @ISA;
@@ -716,7 +716,8 @@ sub checkXSSAttack {
     return 0 unless $value;
 
     # Test value
-    if ( $value =~ m/(?:\0|<|'|"|`|\%(?:00|25|3C|22|27|2C))/ ) {
+    $value =~ s/\%25/\%/g;
+    if ( $value =~ m/(?:\0|<|'|"|`|\%(?:00|3C|22|27|2C))/ ) {
         $self->lmLog( "XSS attack detected (param: $name | value: $value)",
             "warn" );
         return $self->{checkXSS};
@@ -1232,7 +1233,9 @@ sub _deleteSession {
     if ( $self->{securedCookie} >= 2 ) {
 
         # Try to find a linked http session (securedCookie == 2)
-        if ( my $id2 = $session->data->{_httpSession} ) {
+        if ( $self->{securedCookie} == 2
+            and my $id2 = $session->data->{_httpSession} )
+        {
             if ( my $session2 = $self->getApacheSession( $id2, 1 ) ) {
                 $session2->remove;
                 if ( $session2->error ) {
@@ -1428,6 +1431,7 @@ sub getSkin {
 #    - setAuthSessionInfo
 #    - authenticate
 #    - authFinish
+#    - authPostStore
 #  - userDB module:
 #    - userDBInit
 #    - getUser
@@ -1454,8 +1458,8 @@ sub process {
           modifyPassword setSessionInfo setMacros setGroups
           setPersistentSessionInfo setLocalGroups sendPasswordMail
           authenticate authFinish userDBFinish passwordDBFinish
-          grantSession removeOther store buildCookie checkNotification
-          issuerForAuthUser autoRedirect)
+          grantSession removeOther store authPostStore buildCookie
+          checkNotification issuerForAuthUser autoRedirect)
     );
     $self->updateStatus;
     return ( ( $self->{error} > 0 ) ? 0 : 1 );
@@ -1849,7 +1853,7 @@ sub existingSession {
                 qw(issuerDBInit authInit issuerForUnAuthUser extractFormInfo
                   userDBInit getUser setAuthSessionInfo setSessionInfo
                   setMacros setGroups setPersistentSessionInfo
-                  setLocalGroups authenticate authFinish userDBFinish store)
+                  setLocalGroups authenticate authFinish userDBFinish store authPostStore)
             );
             return $self->{error} || PE_DONE;
         }
@@ -2408,6 +2412,24 @@ sub authFinish {
     return $self->{error};
 }
 
+## @apmethod int authPostStore
+# Call authPostStore method from authentication module
+# @return Lemonldap::NG::Portal constant
+sub authPostStore {
+    my $self = shift;
+
+    eval { $self->{error} = $self->SUPER::authPostStore; };
+    if ($@) {
+        $self->lmLog(
+"Optional authPostStore method not defined in current authentication module: $@",
+            'debug'
+        );
+        return PE_OK;
+    }
+
+    return $self->{error};
+}
+
 ## @apmethod int userDBFinish
 # Call userDBFinish method from userDB module
 # @return Lemonldap::NG::Portal constant
