@@ -9,7 +9,7 @@ use strict;
 use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_DBI;    #inherits
 
-our $VERSION = '1.2.2_01';
+our $VERSION = '1.4.9';
 
 ## @apmethod int userDBInit()
 # Set default values
@@ -62,7 +62,7 @@ sub getUser {
     }
 
     unless ( $self->{entry} = $sth->fetchrow_hashref() ) {
-        $self->lmLog( "User $user not found", 'notice' );
+        $self->_sub( 'userNotice', "User $user not found" );
         return PE_BADCREDENTIALS;
     }
 
@@ -83,7 +83,7 @@ sub getUser {
         my $results;
 
         unless ( $results = $sth->fetchrow_hashref() ) {
-            $self->lmLog( "User $user not found", 'notice' );
+            $self->_sub( 'userNotice', "User $user not found" );
             return PE_BADCREDENTIALS;
         }
 
@@ -102,12 +102,8 @@ sub setSessionInfo {
     # Set _user unless already defined
     $self->{sessionInfo}->{_user} ||= $self->{user};
 
-    # Return if no data to collect
-    return PE_OK
-      unless ( $self->{exportedVars}
-        and ref( $self->{exportedVars} ) eq 'HASH' );
-
-    while ( my ( $var, $attr ) = each %{ $self->{exportedVars} } ) {
+    my %vars = ( %{ $self->{exportedVars} }, %{ $self->{dbiExportedVars} } );
+    while ( my ( $var, $attr ) = each %vars ) {
         $self->{sessionInfo}->{$var} = $self->{entry}->{$attr}
           if ( defined $self->{entry}->{$attr} );
     }
@@ -122,47 +118,5 @@ sub setGroups {
     PE_OK;
 }
 
-## @method boolean setUserDBValue(string key, string value)
-# Store a value in UserDB
-# @param key Key in user information
-# @param value Value to store
-# @return result
-sub setUserDBValue {
-    my ( $self, $key, $value ) = splice @_;
-
-    # Mandatory attributes
-    return 0 unless defined $key;
-
-    # Write in database
-    $self->lmLog( "Replace $key attribute in database with value $value",
-        'debug' );
-
-    # Connect
-    my $dbh =
-      $self->dbh( $self->{dbiUserChain}, $self->{dbiUserUser},
-        $self->{dbiUserPassword} );
-    return 0 unless $dbh;
-
-    my $table = $self->{dbiUserTable};
-    my $pivot = $self->{userPivot};
-    my $user  = $self->{user};
-
-    $user =~ s/'/''/g;
-    my $sth;
-
-    eval {
-        $sth = $dbh->prepare("UPDATE $table SET $key = $value WHERE $pivot=?");
-        $sth->execute($user);
-    };
-
-    # Check result
-    if ($@) {
-        $self->lmLog( "DBI error: $@", 'error' );
-        return 0;
-    }
-
-    return 1;
-}
-
 1;
 
