@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::_LibAccess;
 require SOAP::Lite;
 use base qw(Lemonldap::NG::Portal::_LibAccess);
 
-our $VERSION = '1.4.2';
+our $VERSION = '1.4.6';
 
 ## @method void startSoapServices()
 # Check the URI requested (PATH_INFO environment variable) and launch the
@@ -349,8 +349,12 @@ sub exportedAttr {
         return split /\s+/, $self->{exportedAttr};
     }
     else {
-        my @attributes =
-          ( 'authenticationLevel', 'groups', 'ipAddr', 'startTime', '_utime' );
+        my @attributes = (
+            'authenticationLevel', 'groups',
+            'ipAddr',              'startTime',
+            '_utime',              '_lastSeen',
+            '_session_id',
+        );
         if ( my $exportedAttr = $self->{exportedAttr} ) {
             $exportedAttr =~ s/^\s*\+\s+//;
             @attributes = ( @attributes, split( /\s+/, $exportedAttr ) );
@@ -378,8 +382,7 @@ sub _buildSoapHash {
     @keys = keys %$h unless (@keys);
     foreach (@keys) {
         if ( ref( $h->{$_} ) eq 'ARRAY' ) {
-            push @tmp,
-              SOAP::Data->name( $_, \SOAP::Data->value( @{ $h->{$_} } ) );
+            push @tmp, SOAP::Data->name( $_, @{ $h->{$_} } );
         }
         elsif ( ref( $h->{$_} ) ) {
             push @tmp, SOAP::Data->name( $_ => _buildSoapHash( $h->{$_} ) );
